import * as _visoning_vue_floating_core from '@visoning/vue-floating-core';
import { VirtualElement, Middleware, ReferenceType } from '@visoning/vue-floating-core';
export { Middleware, MiddlewareData, Placement, Strategy, VirtualElement } from '@visoning/vue-floating-core';
import { AutoUpdateOptions as AutoUpdateOptions$1 } from '@floating-ui/dom';
import * as _floating_ui_core from '@floating-ui/core';
import { Strategy, Placement, MiddlewareData, OffsetOptions, ShiftOptions, FlipOptions, AutoPlacementOptions } from '@floating-ui/core';
import * as _visoning_vue_floating_interactions from '@visoning/vue-floating-interactions';
import { Delay as Delay$1, InteractionInfo as InteractionInfo$1 } from '@visoning/vue-floating-interactions';
import * as vue_demi from 'vue-demi';
import { PropType, VNode, ExtractPropTypes, Ref } from 'vue-demi';
import * as _floating_ui_core_src_types from '@floating-ui/core/src/types';

interface UseFloatingData {
    x: number | null;
    y: number | null;
    strategy: Strategy;
    placement: Placement;
    middlewareData: MiddlewareData;
}

declare type UseAutoUpdateOptions = Partial<AutoUpdateOptions$1> & {
    /**
     * @default false
     */
    disabled?: boolean;
};

declare type FloatingData = UseFloatingData;
declare type AutoUpdateOptions = UseAutoUpdateOptions;

interface PopupExposed {
    getFloatingData: () => FloatingData | undefined;
    updatePosition: () => void;
}
declare type PopupSlotProps = FloatingData;
declare type Interaction = 'click' | 'hover' | 'focus';
declare const PopupProps: {
    /**
     * Whether to open popup.
     */
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    /**
     * Default open when not manually set.
     */
    readonly defaultOpen: BooleanConstructor;
    /**
     * Whether to disable the floating.
     */
    readonly disabled: BooleanConstructor;
    /**
     * You can position a floating element relative to a virtual element instead of a real one.
     * This enables things like positioning context menus or following the cursor.
     * @see https://floating-ui.com/docs/virtual-elements
     */
    readonly virtualElement: PropType<VirtualElement>;
    /**
     * When this value is `true`, popup will be teleport to the target.
     * The teleport to target must be already in the DOM when the <Teleport> component is mounted.
     * @see https://vuejs.org/guide/built-ins/teleport.html
     *
     * Or you can customize the teleport logic, set `appendTo` to false, and use `floatingWrapper`,
     * for simple example
     * ```tsx
     * {
     *   appendTo: false,
     *   floatingWrapper: (floating) => h(
     *    Teleport,
     *    {
     *      to: anyTarget
     *    },
     *    {
     *      default: () => [floating]
     *    }
     *   )
     * }
     * ```
     * @default "body"
     */
    readonly appendTo: {
        type: PropType<string | false | HTMLElement>;
        default: string;
    };
    /**
     * Which actions cause popup shown. enum of 'hover','click','focus'.
     */
    readonly interactions: {
        readonly type: PropType<Interaction[]>;
        readonly default: () => string[];
    };
    /**
     * Common delay in ms, before popup is open/close.
     */
    readonly delay: PropType<Delay$1>;
    /**
     * Delay in ms, before popup is open/close on pointer click.
     */
    readonly clickDelay: PropType<Delay$1>;
    /**
     * Delay in ms, before popup is open/close on pointer enter/leave.
     */
    readonly hoverDelay: PropType<Delay$1>;
    /**
     * Delay in ms, before popup is open/close on focus/blur.
     */
    readonly focusDelay: PropType<Delay$1>;
    /**
     * Whether to keep the popup open on mouse hover
     */
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * Whether to close by clicking outside.
     * @default true
     */
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * When this value is `false`, even if the popup is closed, floating will update the position as needed,
     * unless popup is disabled.
     */
    readonly autoUpdateOnClosed: BooleanConstructor;
    /**
     * Displaces the popup element from its core placement along the specified axes.
     * @see https://floating-ui.com/docs/offset
     */
    readonly offset: PropType<OffsetOptions>;
    /**
     * Moves the popup element along the specified axes in order to keep it in view.
     * @default true
     * @see https://floating-ui.com/docs/shift
     */
    readonly shift: {
        readonly type: PropType<boolean | ShiftOptions>;
        readonly default: true;
    };
    /**
     * Changes the placement of the popup element to the opposite one by default in order to keep it in view.
     * @see https://floating-ui.com/docs/flip
     */
    readonly flip: PropType<boolean | FlipOptions>;
    /**
     * Chooses the placement that has the most space available automatically.
     *
     * You’ll want to use this instead of `flip` if you don't want to give the popup element a “preferred” placement
     * and let it choose a placement for you.
     * @see https://floating-ui.com/docs/autoPlacement
     */
    readonly autoPlacement: PropType<boolean | AutoPlacementOptions>;
    /**
     * This determines whether GPU-accelerated styles are used to position the popup.
     * When this value is `true`, popup will use the 3D transforms.
     * When this value is `false`, popup will use top/left properties.
     */
    readonly gpuAcceleration: BooleanConstructor;
    /**
     * Whether destroy popup when closed.
     */
    readonly destoryedOnClosed: BooleanConstructor;
    /**
     * HTML attributes of node.
     */
    readonly referenceProps: PropType<Record<string, any>>;
    /**
     * HTML attributes of node.
     */
    readonly popupProps: PropType<Record<string, any>>;
    /**
     * Custom popup node wrapper.
     */
    readonly popupWrapper: PropType<(popup: VNode | null) => VNode>;
    /**
     * Custom floating node wrapper.
     */
    readonly floatingWrapper: PropType<(popup: VNode | null) => VNode>;
    /**
     * Popup z-index.
     */
    readonly zIndex: NumberConstructor;
    /**
     * Callback on open status changes.
     */
    readonly 'onUpdate:open': PropType<(open: boolean, info: InteractionInfo$1) => void>;
    /**
     * Callback on popup open.
     */
    readonly onOpen: PropType<(info: InteractionInfo$1) => void>;
    /**
     * Callback on popup close.
     */
    readonly onClose: PropType<(info: InteractionInfo$1) => void>;
    /**
     * Callback on floating data update.
     */
    readonly onFloatingDataUpdate: PropType<(data: FloatingData) => void>;
    readonly placement: {
        readonly type: PropType<_floating_ui_core.Placement>;
        readonly default: _floating_ui_core.Placement;
    };
    readonly strategy: {
        readonly type: PropType<_floating_ui_core.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core.Middleware[]>;
    readonly autoUpdate: {
        readonly type: PropType<boolean | _visoning_vue_floating_core.UseAutoUpdateOptions>;
        readonly default: true;
    };
};
declare type PopupProps = ExtractPropTypes<typeof PopupProps>;

declare const Popup: vue_demi.DefineComponent<{
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly disabled: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: {
        type: vue_demi.PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly interactions: {
        readonly type: vue_demi.PropType<Interaction[]>;
        readonly default: () => string[];
    };
    readonly delay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly clickDelay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly hoverDelay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly focusDelay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly shift: {
        readonly type: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: vue_demi.PropType<Record<string, any>>;
    readonly popupProps: vue_demi.PropType<Record<string, any>>;
    readonly popupWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: InteractionInfo$1) => void>;
    readonly onOpen: vue_demi.PropType<(info: InteractionInfo$1) => void>;
    readonly onClose: vue_demi.PropType<(info: InteractionInfo$1) => void>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: _visoning_vue_floating_core.UseFloatingData) => void>;
    readonly placement: {
        readonly type: vue_demi.PropType<_floating_ui_core.Placement>;
        readonly default: _floating_ui_core.Placement;
    };
    readonly strategy: {
        readonly type: vue_demi.PropType<_floating_ui_core.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: vue_demi.PropType<Middleware[]>;
    readonly autoUpdate: {
        readonly type: vue_demi.PropType<boolean | _visoning_vue_floating_core.UseAutoUpdateOptions>;
        readonly default: true;
    };
}, () => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, {}, string, vue_demi.VNodeProps & vue_demi.AllowedComponentProps & vue_demi.ComponentCustomProps, Readonly<vue_demi.ExtractPropTypes<{
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly disabled: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<_visoning_vue_floating_core.VirtualElement>;
    readonly appendTo: {
        type: vue_demi.PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly interactions: {
        readonly type: vue_demi.PropType<Interaction[]>;
        readonly default: () => string[];
    };
    readonly delay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly clickDelay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly hoverDelay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly focusDelay: vue_demi.PropType<_visoning_vue_floating_interactions.Delay>;
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly shift: {
        readonly type: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: vue_demi.PropType<Record<string, any>>;
    readonly popupProps: vue_demi.PropType<Record<string, any>>;
    readonly popupWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: InteractionInfo$1) => void>;
    readonly onOpen: vue_demi.PropType<(info: InteractionInfo$1) => void>;
    readonly onClose: vue_demi.PropType<(info: InteractionInfo$1) => void>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: _visoning_vue_floating_core.UseFloatingData) => void>;
    readonly placement: {
        readonly type: vue_demi.PropType<_floating_ui_core.Placement>;
        readonly default: _floating_ui_core.Placement;
    };
    readonly strategy: {
        readonly type: vue_demi.PropType<_floating_ui_core.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: vue_demi.PropType<Middleware[]>;
    readonly autoUpdate: {
        readonly type: vue_demi.PropType<boolean | _visoning_vue_floating_core.UseAutoUpdateOptions>;
        readonly default: true;
    };
}>>, {
    readonly placement: _floating_ui_core.Placement;
    readonly strategy: _floating_ui_core.Strategy;
    readonly shift: boolean | _floating_ui_core.ShiftOptions;
    readonly disabled: boolean;
    readonly autoUpdate: boolean | _visoning_vue_floating_core.UseAutoUpdateOptions;
    readonly open: boolean;
    readonly closeWhenClickOutside: boolean;
    readonly keepOpenWhenPopupHover: boolean;
    readonly defaultOpen: boolean;
    readonly appendTo: string | false | HTMLElement;
    readonly interactions: Interaction[];
    readonly autoUpdateOnClosed: boolean;
    readonly gpuAcceleration: boolean;
    readonly destoryedOnClosed: boolean;
}>;

declare type ForwardReferenceType = ReferenceType | null;
interface ForwardReferenceContextValue {
    forwardReference: (reference: ForwardReferenceType) => void;
}
declare const useSafeReferenceForwardContent: () => ForwardReferenceContextValue | undefined;
declare const useReferenceForwardContext: () => ForwardReferenceContextValue;
declare const providePopupContextValue: (contextValue: ForwardReferenceContextValue) => void;
declare const createReferenceForwardContext: (referenceRef?: Ref<ForwardReferenceType>) => Ref<ForwardReferenceType>;

interface InteractionInfo {
    type: string | null;
    event?: Event | null;
}
declare type DelayType = 'open' | 'close';
declare type Delay = number | Partial<Record<DelayType, number>> | undefined;

interface PopoverExposed {
    floatingData: FloatingData | undefined;
    update: () => void;
}
declare type PopoverArrowSlotProps = PopupSlotProps;
declare type CreateArrow = (props: PopoverArrowSlotProps) => VNode | null;
declare const PopoverExtendsPopupProps: {
    readonly placement: {
        readonly type: PropType<_floating_ui_core_src_types.Placement>;
        readonly default: _floating_ui_core_src_types.Placement;
    };
    readonly strategy: {
        readonly type: PropType<_floating_ui_core_src_types.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core_src_types.Middleware[]>;
    readonly shift: {
        readonly type: PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: PropType<VirtualElement>;
    readonly appendTo: {
        type: PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly interactions: {
        readonly type: PropType<Interaction[]>;
        readonly default: () => string[];
    };
    readonly clickDelay: PropType<Delay>;
    readonly hoverDelay: PropType<Delay>;
    readonly focusDelay: PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: PropType<(info: InteractionInfo) => void>;
    readonly onClose: PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: PropType<(data: UseFloatingData) => void>;
};
declare const PopoverProps: {
    /**
     * support: string | VNode | slot
     */
    readonly content: PropType<string | VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    /**
     * support: string | VNode | slot
     */
    readonly title: PropType<string | VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    /**
     * The theme of the popover.
     * @default 'light'
     */
    readonly theme: {
        readonly type: PropType<"dark" | "light">;
        readonly default: "light";
    };
    /**
     * @see https://cn.vuejs.org/guide/built-ins/transition.html
     */
    readonly transitionProps: {
        readonly type: PropType<string | Record<string, any>>;
        readonly default: "visoning-popover";
    };
    /**
     * Whether to show arrow if set.
     * @default true
     */
    readonly showArrow: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * For style uniformity, we will never enable the configuration of arrow middleware,
     * you can customize arrow to make arrow more as expected.
     *
     * support: VNode | slot
     */
    readonly arrow: PropType<VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | CreateArrow | null>;
    /**
     * HTML attributes of node.
     */
    readonly arrowProps: PropType<Record<string, any>>;
    /**
     * HTML attributes of node.
     */
    readonly popoverProps: PropType<Record<string, any>>;
    /**
     * Custom popover node wrapper.
     */
    readonly popoverWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly placement: {
        readonly type: PropType<_floating_ui_core_src_types.Placement>;
        readonly default: _floating_ui_core_src_types.Placement;
    };
    readonly strategy: {
        readonly type: PropType<_floating_ui_core_src_types.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core_src_types.Middleware[]>;
    readonly shift: {
        readonly type: PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: PropType<VirtualElement>;
    readonly appendTo: {
        type: PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly interactions: {
        readonly type: PropType<Interaction[]>;
        readonly default: () => string[];
    };
    readonly clickDelay: PropType<Delay>;
    readonly hoverDelay: PropType<Delay>;
    readonly focusDelay: PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: PropType<(info: InteractionInfo) => void>;
    readonly onClose: PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: PropType<(data: UseFloatingData) => void>;
};
declare type PopoverProps = ExtractPropTypes<typeof PopoverProps>;

declare const Popover: vue_demi.DefineComponent<{
    readonly content: vue_demi.PropType<string | vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly title: vue_demi.PropType<string | vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly theme: {
        readonly type: vue_demi.PropType<"dark" | "light">;
        readonly default: "light";
    };
    readonly transitionProps: {
        readonly type: vue_demi.PropType<string | Record<string, any>>;
        readonly default: "visoning-popover";
    };
    readonly showArrow: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly arrow: vue_demi.PropType<vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | CreateArrow | null>;
    readonly arrowProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly placement: {
        readonly type: vue_demi.PropType<_floating_ui_core.Placement>;
        readonly default: _floating_ui_core.Placement;
    };
    readonly strategy: {
        readonly type: vue_demi.PropType<_floating_ui_core.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core.Middleware[]>;
    readonly shift: {
        readonly type: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: vue_demi.PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: vue_demi.PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<VirtualElement>;
    readonly appendTo: {
        type: vue_demi.PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly interactions: {
        readonly type: vue_demi.PropType<Interaction[]>;
        readonly default: () => string[];
    };
    readonly clickDelay: vue_demi.PropType<Delay>;
    readonly hoverDelay: vue_demi.PropType<Delay>;
    readonly focusDelay: vue_demi.PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onClose: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: UseFloatingData) => void>;
}, () => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, {}, string, vue_demi.VNodeProps & vue_demi.AllowedComponentProps & vue_demi.ComponentCustomProps, Readonly<vue_demi.ExtractPropTypes<{
    readonly content: vue_demi.PropType<string | vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly title: vue_demi.PropType<string | vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly theme: {
        readonly type: vue_demi.PropType<"dark" | "light">;
        readonly default: "light";
    };
    readonly transitionProps: {
        readonly type: vue_demi.PropType<string | Record<string, any>>;
        readonly default: "visoning-popover";
    };
    readonly showArrow: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly arrow: vue_demi.PropType<vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | CreateArrow | null>;
    readonly arrowProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverProps: vue_demi.PropType<Record<string, any>>;
    readonly popoverWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly placement: {
        readonly type: vue_demi.PropType<_floating_ui_core.Placement>;
        readonly default: _floating_ui_core.Placement;
    };
    readonly strategy: {
        readonly type: vue_demi.PropType<_floating_ui_core.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core.Middleware[]>;
    readonly shift: {
        readonly type: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: vue_demi.PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: vue_demi.PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<VirtualElement>;
    readonly appendTo: {
        type: vue_demi.PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly interactions: {
        readonly type: vue_demi.PropType<Interaction[]>;
        readonly default: () => string[];
    };
    readonly clickDelay: vue_demi.PropType<Delay>;
    readonly hoverDelay: vue_demi.PropType<Delay>;
    readonly focusDelay: vue_demi.PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onClose: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: UseFloatingData) => void>;
}>>, {
    readonly placement: _floating_ui_core.Placement;
    readonly strategy: _floating_ui_core.Strategy;
    readonly shift: boolean | _floating_ui_core.ShiftOptions;
    readonly disabled: boolean;
    readonly autoUpdate: boolean | UseAutoUpdateOptions;
    readonly open: boolean;
    readonly closeWhenClickOutside: boolean;
    readonly keepOpenWhenPopupHover: boolean;
    readonly defaultOpen: boolean;
    readonly appendTo: string | false | HTMLElement;
    readonly interactions: Interaction[];
    readonly autoUpdateOnClosed: boolean;
    readonly gpuAcceleration: boolean;
    readonly destoryedOnClosed: boolean;
    readonly theme: "dark" | "light";
    readonly transitionProps: string | Record<string, any>;
    readonly showArrow: boolean;
}>;

declare const Tooltip: vue_demi.DefineComponent<{
    readonly content: vue_demi.PropType<string | vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly textAlign: {
        readonly type: vue_demi.PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
        readonly default: "start";
    };
    readonly tooltipProps: vue_demi.PropType<Record<string, any>>;
    readonly tooltipWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly placement: {
        readonly type: vue_demi.PropType<_floating_ui_core_src_types.Placement>;
        readonly default: _floating_ui_core_src_types.Placement;
    };
    readonly strategy: {
        readonly type: vue_demi.PropType<_floating_ui_core_src_types.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core_src_types.Middleware[]>;
    readonly shift: {
        readonly type: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: vue_demi.PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: vue_demi.PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<VirtualElement>;
    readonly appendTo: {
        type: vue_demi.PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly clickDelay: vue_demi.PropType<Delay>;
    readonly hoverDelay: vue_demi.PropType<Delay>;
    readonly focusDelay: vue_demi.PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onClose: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: UseFloatingData) => void>;
}, () => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, {}, string, vue_demi.VNodeProps & vue_demi.AllowedComponentProps & vue_demi.ComponentCustomProps, Readonly<vue_demi.ExtractPropTypes<{
    readonly content: vue_demi.PropType<string | vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly textAlign: {
        readonly type: vue_demi.PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
        readonly default: "start";
    };
    readonly tooltipProps: vue_demi.PropType<Record<string, any>>;
    readonly tooltipWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly placement: {
        readonly type: vue_demi.PropType<_floating_ui_core_src_types.Placement>;
        readonly default: _floating_ui_core_src_types.Placement;
    };
    readonly strategy: {
        readonly type: vue_demi.PropType<_floating_ui_core_src_types.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: vue_demi.PropType<_floating_ui_core_src_types.Middleware[]>;
    readonly shift: {
        readonly type: vue_demi.PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: vue_demi.PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: vue_demi.PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: vue_demi.PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: vue_demi.PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: vue_demi.PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: vue_demi.PropType<VirtualElement>;
    readonly appendTo: {
        type: vue_demi.PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly clickDelay: vue_demi.PropType<Delay>;
    readonly hoverDelay: vue_demi.PropType<Delay>;
    readonly focusDelay: vue_demi.PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: vue_demi.PropType<Record<string, any>>;
    readonly floatingWrapper: vue_demi.PropType<(popup: vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => vue_demi.VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': vue_demi.PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onClose: vue_demi.PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: vue_demi.PropType<(data: UseFloatingData) => void>;
}>>, {
    readonly placement: _floating_ui_core_src_types.Placement;
    readonly strategy: _floating_ui_core_src_types.Strategy;
    readonly shift: boolean | _floating_ui_core.ShiftOptions;
    readonly disabled: boolean;
    readonly autoUpdate: boolean | UseAutoUpdateOptions;
    readonly open: boolean;
    readonly closeWhenClickOutside: boolean;
    readonly keepOpenWhenPopupHover: boolean;
    readonly defaultOpen: boolean;
    readonly appendTo: string | false | HTMLElement;
    readonly autoUpdateOnClosed: boolean;
    readonly gpuAcceleration: boolean;
    readonly destoryedOnClosed: boolean;
    readonly textAlign: "right" | "left" | "start" | "end" | "center" | "justify" | "match-parent";
}>;

interface TooltipExposed {
    floatingData: FloatingData | undefined;
    update: () => void;
}
declare type TooltipArrowSlotProps = PopoverArrowSlotProps;
declare const TooltipExtendsPopoverProps: {
    readonly placement: {
        readonly type: PropType<_floating_ui_core_src_types.Placement>;
        readonly default: _floating_ui_core_src_types.Placement;
    };
    readonly strategy: {
        readonly type: PropType<_floating_ui_core_src_types.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core_src_types.Middleware[]>;
    readonly shift: {
        readonly type: PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: PropType<VirtualElement>;
    readonly appendTo: {
        type: PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly clickDelay: PropType<Delay>;
    readonly hoverDelay: PropType<Delay>;
    readonly focusDelay: PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: PropType<(info: InteractionInfo) => void>;
    readonly onClose: PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: PropType<(data: UseFloatingData) => void>;
};
declare const TooltipProps: {
    /**
     * support: string | VNode | slot
     */
    readonly content: PropType<string | VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    /**
     * align tooltip content. enum of CSS text-align.
     * @default 'start'
     */
    readonly textAlign: {
        readonly type: PropType<"right" | "left" | "start" | "end" | "center" | "justify" | "match-parent">;
        readonly default: "start";
    };
    /**
     * HTML attributes of node.
     */
    readonly tooltipProps: PropType<Record<string, any>>;
    /**
     * Custom tooltip node wrapper.
     */
    readonly tooltipWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly placement: {
        readonly type: PropType<_floating_ui_core_src_types.Placement>;
        readonly default: _floating_ui_core_src_types.Placement;
    };
    readonly strategy: {
        readonly type: PropType<_floating_ui_core_src_types.Strategy>;
        readonly default: "absolute";
    };
    readonly middleware: PropType<_floating_ui_core_src_types.Middleware[]>;
    readonly shift: {
        readonly type: PropType<boolean | _floating_ui_core.ShiftOptions>;
        readonly default: true;
    };
    readonly autoPlacement: PropType<boolean | _floating_ui_core.AutoPlacementOptions>;
    readonly flip: PropType<boolean | _floating_ui_core.FlipOptions>;
    readonly offset: PropType<_floating_ui_core.OffsetOptions>;
    readonly disabled: BooleanConstructor;
    readonly autoUpdate: {
        readonly type: PropType<boolean | UseAutoUpdateOptions>;
        readonly default: true;
    };
    readonly open: {
        readonly type: BooleanConstructor;
        readonly default: undefined;
    };
    readonly delay: PropType<Delay>;
    readonly closeWhenClickOutside: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly keepOpenWhenPopupHover: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    readonly defaultOpen: BooleanConstructor;
    readonly virtualElement: PropType<VirtualElement>;
    readonly appendTo: {
        type: PropType<string | false | HTMLElement>;
        default: string;
    };
    readonly clickDelay: PropType<Delay>;
    readonly hoverDelay: PropType<Delay>;
    readonly focusDelay: PropType<Delay>;
    readonly autoUpdateOnClosed: BooleanConstructor;
    readonly gpuAcceleration: BooleanConstructor;
    readonly destoryedOnClosed: BooleanConstructor;
    readonly referenceProps: PropType<Record<string, any>>;
    readonly floatingWrapper: PropType<(popup: VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }> | null) => VNode<vue_demi.RendererNode, vue_demi.RendererElement, {
        [key: string]: any;
    }>>;
    readonly zIndex: NumberConstructor;
    readonly 'onUpdate:open': PropType<(open: boolean, info: InteractionInfo) => void>;
    readonly onOpen: PropType<(info: InteractionInfo) => void>;
    readonly onClose: PropType<(info: InteractionInfo) => void>;
    readonly onFloatingDataUpdate: PropType<(data: UseFloatingData) => void>;
};
declare type TooltipProps = ExtractPropTypes<typeof TooltipProps>;

export { AutoUpdateOptions, CreateArrow, FloatingData, ForwardReferenceContextValue, ForwardReferenceType, Interaction, Popover, PopoverArrowSlotProps, PopoverExposed, PopoverExtendsPopupProps, PopoverProps, Popup, PopupExposed, PopupProps, PopupSlotProps, Tooltip, TooltipArrowSlotProps, TooltipExposed, TooltipExtendsPopoverProps, TooltipProps, createReferenceForwardContext, providePopupContextValue, useReferenceForwardContext, useSafeReferenceForwardContent };
